@@ -21,7 +21,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#include <config.h>
 #endif
 
 #include <stdlib.h>
@@ -55,10 +55,6 @@
 #include "gpm-icon-names.h"
 #include "egg-console-kit.h"
 
-#if !GTK_CHECK_VERSION(3,0,0)
-#define gtk_widget_get_preferred_size(x,y,z) gtk_widget_size_request(x,y)
-#endif
-
 #define GPM_BACKLIGHT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GPM_TYPE_BACKLIGHT, GpmBacklightPrivate))
 
 struct GpmBacklightPrivate
@@ -214,11 +210,9 @@ gpm_backlight_dialog_show (GpmBacklight *backlight)
 	GdkScreen     *pointer_screen;
 	GdkRectangle   geometry;
 	int            monitor;
-#if GTK_CHECK_VERSION(3,0,0)
         GdkDisplay    *display;
         GdkDeviceManager *device_manager;
         GdkDevice     *device;
-#endif
 
 	/*
 	 * get the window size
@@ -236,7 +230,6 @@ gpm_backlight_dialog_show (GpmBacklight *backlight)
 	}
 
 	pointer_screen = NULL;
-#if GTK_CHECK_VERSION(3,0,0)
         display = gtk_widget_get_display (backlight->priv->popup);
         device_manager = gdk_display_get_device_manager (display);
         device = gdk_device_manager_get_client_pointer (device_manager);
@@ -244,13 +237,7 @@ gpm_backlight_dialog_show (GpmBacklight *backlight)
 				 &pointer_screen,
 				 &pointer_x,
 				 &pointer_y);
-#else
-	gdk_display_get_pointer (gtk_widget_get_display (backlight->priv->popup),
-				 &pointer_screen,
-				 &pointer_x,
-				 &pointer_y,
-				 NULL);
-#endif
+
 	monitor = gdk_screen_get_monitor_at_point (pointer_screen,
 						   pointer_x,
 						   pointer_y);
