@@ -20,7 +20,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#include <config.h>
 #endif
 
 #include <stdlib.h>
@@ -270,15 +270,11 @@ gpm_brightness_setup_display (GpmBrightness *brightness)
 		egg_debug ("RandR version %d.%d too old", major, minor);
 		return FALSE;
 	}
-	/* Can we support "Backlight" */
-	brightness->priv->backlight = XInternAtom (brightness->priv->dpy, "Backlight", True);
+	/* can we support BACKLIGHT */
+	brightness->priv->backlight = XInternAtom (brightness->priv->dpy, "BACKLIGHT", True);
 	if (brightness->priv->backlight == None) {
-		/* Do we support "BACKLIGHT" (legacy) */
-		brightness->priv->backlight = XInternAtom (brightness->priv->dpy, "BACKLIGHT", True);
-		if (brightness->priv->backlight == None) {
-			egg_debug ("No outputs have backlight property");
-			return FALSE;
-		}
+		egg_debug ("No outputs have backlight property");
+		return FALSE;
 	}
 	return TRUE;
 }
